summaryrefslogtreecommitdiffstats
path: root/quanta/parts/kafka/htmlenhancer.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/parts/kafka/htmlenhancer.h')
-rw-r--r--quanta/parts/kafka/htmlenhancer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/quanta/parts/kafka/htmlenhancer.h b/quanta/parts/kafka/htmlenhancer.h
index 73c62251..065654a4 100644
--- a/quanta/parts/kafka/htmlenhancer.h
+++ b/quanta/parts/kafka/htmlenhancer.h
@@ -47,10 +47,10 @@ public:
* The DOM::Node must be built before calling this
* function.
* @param node The Node we want to enhance.
* @param tqparentDNode the tqparent DOM::Node of the root DOM::Node of node.
* @param nextDNode the DOM::Node next to the root DOM::Node of node.
*/
- virtual bool enhanceNode(Node *node, DOM::Node tqparentDNode, DOM::Node nextDNode);
+ virtual bool enhanceNode(Node *node, DOM::Node parentDNode, DOM::Node nextDNode);
/**
* This functions is called once the whole DOM::Node tree is built. It will add empty
@@ -47,10 +47,10 @@ public:
* function.
* @param node The Node we want to enhance.
- * @param tqparentDNode the tqparent DOM::Node of the root DOM::Node of node.
+ * @param parentDNode the tqparent DOM::Node of the root DOM::Node of node.
* @param nextDNode the DOM::Node next to the root DOM::Node of node.
*/